@@ -35,6 +35,7 @@ from ironic_lib.openstack.common import imageutils
 
 from ironic_lib.common.i18n import _
 from ironic_lib.common.i18n import _LE
+from ironic_lib.common.i18n import _LI
 from ironic_lib.common.i18n import _LW
 from ironic_lib import disk_partitioner
 from ironic_lib import exception
@@ -66,8 +67,6 @@ LOG = logging.getLogger(__name__)
 _PARTED_PRINT_RE = re.compile(r"^(\d+):([\d\.]+)MiB:"
                               "([\d\.]+)MiB:([\d\.]+)MiB:(\w*)::(\w*)")
 
-_ISCSI_RE = re.compile(r"^ip-[\d+.]*:\w+-iscsi-[\w+.]*-lun-\d+")
-
 
 def list_partitions(device):
     """Get partitions information from given device.
@@ -100,12 +99,6 @@ def list_partitions(device):
     return result
 
 
-def is_iscsi_device(dev):
-    """check whether the device path belongs to an iscsi device. """
-    basename = os.path.basename(dev)
-    return bool(_ISCSI_RE.match(basename))
-
-
 def get_disk_identifier(dev):
     """Get the disk identifier from the disk being exposed by the ramdisk.
 
@@ -129,8 +122,8 @@ def get_disk_identifier(dev):
 
 
 def make_partitions(dev, root_mb, swap_mb, ephemeral_mb,
-                    configdrive_mb, commit=True, boot_option="netboot",
-                    boot_mode="bios"):
+                    configdrive_mb, node_uuid, commit=True,
+                    boot_option="netboot", boot_mode="bios"):
     """Partition the disk device.
 
     Create partitions for root, swap, ephemeral and configdrive on a
@@ -147,18 +140,15 @@ def make_partitions(dev, root_mb, swap_mb, ephemeral_mb,
         partitions will not be written to disk.
     :param boot_option: Can be "local" or "netboot". "netboot" by default.
     :param boot_mode: Can be "bios" or "uefi". "bios" by default.
+    :param node_uuid: Node's uuid. Used for logging.
     :returns: A dictionary containing the partition type as Key and partition
         path as Value for the partitions created by this method.
 
     """
-    LOG.debug("Starting to partition the disk device: %(dev)s",
-              {'dev': dev})
-
-    if is_iscsi_device(dev):
-        part_template = dev + '-part%d'
-    else:
-        part_template = dev + '%d'
-
+    LOG.debug("Starting to partition the disk device: %(dev)s "
+              "for node %(node)s",
+              {'dev': dev, 'node': node_uuid})
+    part_template = dev + '-part%d'
     part_dict = {}
 
     # For uefi localboot, switch partition table to gpt and create the efi
@@ -173,26 +163,30 @@ def make_partitions(dev, root_mb, swap_mb, ephemeral_mb,
         dp = disk_partitioner.DiskPartitioner(dev)
 
     if ephemeral_mb:
-        LOG.debug("Add ephemeral partition (%(size)d MB) to device: %(dev)s",
-                  {'dev': dev, 'size': ephemeral_mb})
+        LOG.debug("Add ephemeral partition (%(size)d MB) to device: %(dev)s "
+                  "for node %(node)s",
+                  {'dev': dev, 'size': ephemeral_mb, 'node': node_uuid})
         part_num = dp.add_partition(ephemeral_mb)
         part_dict['ephemeral'] = part_template % part_num
     if swap_mb:
-        LOG.debug("Add Swap partition (%(size)d MB) to device: %(dev)s",
-                  {'dev': dev, 'size': swap_mb})
+        LOG.debug("Add Swap partition (%(size)d MB) to device: %(dev)s "
+                  "for node %(node)s",
+                  {'dev': dev, 'size': swap_mb, 'node': node_uuid})
         part_num = dp.add_partition(swap_mb, fs_type='linux-swap')
         part_dict['swap'] = part_template % part_num
     if configdrive_mb:
         LOG.debug("Add config drive partition (%(size)d MB) to device: "
-                  "%(dev)s", {'dev': dev, 'size': configdrive_mb})
+                  "%(dev)s for node %(node)s",
+                  {'dev': dev, 'size': configdrive_mb, 'node': node_uuid})
         part_num = dp.add_partition(configdrive_mb)
         part_dict['configdrive'] = part_template % part_num
 
     # NOTE(lucasagomes): Make the root partition the last partition. This
     # enables tools like cloud-init's growroot utility to expand the root
     # partition until the end of the disk.
-    LOG.debug("Add root partition (%(size)d MB) to device: %(dev)s",
-              {'dev': dev, 'size': root_mb})
+    LOG.debug("Add root partition (%(size)d MB) to device: %(dev)s "
+              "for node %(node)s",
+              {'dev': dev, 'size': root_mb, 'node': node_uuid})
     part_num = dp.add_partition(root_mb, bootable=(boot_option == "local" and
                                                    boot_mode == "bios"))
     part_dict['root'] = part_template % part_num
@@ -334,6 +328,8 @@ def destroy_disk_metadata(dev, node_uuid):
                           {'node': node_uuid,
                            'command': err.cmd,
                            'error': err.stderr})
+    LOG.info(_LI("Disk metadata on %(dev)s successfully destroyed for node "
+                 "%(node)s"), {'dev': dev, 'node': node_uuid})
 
 
 def _get_configdrive(configdrive, node_uuid):
@@ -441,9 +437,13 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
                                                                 node_uuid)
 
         part_dict = make_partitions(dev, root_mb, swap_mb, ephemeral_mb,
-                                    configdrive_mb, commit=commit,
+                                    configdrive_mb, node_uuid,
+                                    commit=commit,
                                     boot_option=boot_option,
                                     boot_mode=boot_mode)
+        LOG.info(_LI("Successfully completed the disk device"
+                     " %(dev)s partitioning for node %(node)s"),
+                 {'dev': dev, "node": node_uuid})
 
         ephemeral_part = part_dict.get('ephemeral')
         swap_part = part_dict.get('swap')
@@ -474,6 +474,9 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
         if configdrive_part:
             # Copy the configdrive content to the configdrive partition
             dd(configdrive_file, configdrive_part)
+            LOG.info(_LI("Configdrive for node %(node)s successfully copied "
+                         "onto partition %(partition)s"),
+                     {'node': node_uuid, 'partition': configdrive_part})
 
     finally:
         # If the configdrive was requested make sure we delete the file
@@ -482,12 +485,20 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
             utils.unlink_without_raise(configdrive_file)
 
     populate_image(image_path, root_part)
+    LOG.info(_LI("Image for %(node)s successfully populated"),
+             {'node': node_uuid})
 
     if swap_part:
         mkfs(dev=swap_part, fs='swap', label='swap1')
+        LOG.info(_LI("Swap partition %(swap)s successfully formatted "
+                     "for node %(node)s"),
+                 {'swap': swap_part, 'node': node_uuid})
 
     if ephemeral_part and not preserve_ephemeral:
         mkfs(dev=ephemeral_part, fs=ephemeral_format, label="ephemeral0")
+        LOG.info(_LI("Ephemeral partition %(ephemeral)s successfully "
+                     "formatted for node %(node)s"),
+                 {'ephemeral': ephemeral_part, 'node': node_uuid})
 
     uuids_to_return = {
         'root uuid': root_part,
