@@ -81,6 +81,7 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
         self.ephemeral_mb = 0
         self.ephemeral_format = None
         self.configdrive_mb = 0
+        self.node_uuid = "12345678-1234-1234-1234-1234567890abcxyz"
         self.dev = '/dev/fake'
         self.swap_part = '/dev/fake-part1'
         self.root_part = '/dev/fake-part2'
@@ -105,11 +106,13 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
         self.assertRaises(exception.InstanceDeployFailure,
                           disk_utils.work_on_disk, self.dev, self.root_mb,
                           self.swap_mb, self.ephemeral_mb,
-                          self.ephemeral_format, self.image_path, 'fake-uuid')
+                          self.ephemeral_format, self.image_path,
+                          self.node_uuid)
         self.mock_ibd.assert_called_once_with(self.root_part)
         self.mock_mp.assert_called_once_with(self.dev, self.root_mb,
                                              self.swap_mb, self.ephemeral_mb,
-                                             self.configdrive_mb, commit=True,
+                                             self.configdrive_mb,
+                                             self.node_uuid, commit=True,
                                              boot_option="netboot",
                                              boot_mode="bios")
 
@@ -120,11 +123,13 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
         self.assertRaises(exception.InstanceDeployFailure,
                           disk_utils.work_on_disk, self.dev, self.root_mb,
                           self.swap_mb, self.ephemeral_mb,
-                          self.ephemeral_format, self.image_path, 'fake-uuid')
+                          self.ephemeral_format, self.image_path,
+                          self.node_uuid)
         self.assertEqual(self.mock_ibd.call_args_list, calls)
         self.mock_mp.assert_called_once_with(self.dev, self.root_mb,
                                              self.swap_mb, self.ephemeral_mb,
-                                             self.configdrive_mb, commit=True,
+                                             self.configdrive_mb,
+                                             self.node_uuid, commit=True,
                                              boot_option="netboot",
                                              boot_mode="bios")
 
@@ -145,11 +150,12 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
         self.assertRaises(exception.InstanceDeployFailure,
                           disk_utils.work_on_disk, self.dev, self.root_mb,
                           self.swap_mb, ephemeral_mb, ephemeral_format,
-                          self.image_path, 'fake-uuid')
+                          self.image_path, self.node_uuid)
         self.assertEqual(self.mock_ibd.call_args_list, calls)
         self.mock_mp.assert_called_once_with(self.dev, self.root_mb,
                                              self.swap_mb, ephemeral_mb,
-                                             self.configdrive_mb, commit=True,
+                                             self.configdrive_mb,
+                                             self.node_uuid, commit=True,
                                              boot_option="netboot",
                                              boot_mode="bios")
 
@@ -173,14 +179,15 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
         self.assertRaises(exception.InstanceDeployFailure,
                           disk_utils.work_on_disk, self.dev, self.root_mb,
                           self.swap_mb, self.ephemeral_mb,
-                          self.ephemeral_format, self.image_path, 'fake-uuid',
-                          preserve_ephemeral=False,
+                          self.ephemeral_format, self.image_path,
+                          self.node_uuid, preserve_ephemeral=False,
                           configdrive=configdrive_url,
                           boot_option="netboot")
         self.assertEqual(self.mock_ibd.call_args_list, calls)
         self.mock_mp.assert_called_once_with(self.dev, self.root_mb,
                                              self.swap_mb, self.ephemeral_mb,
-                                             configdrive_mb, commit=True,
+                                             configdrive_mb, self.node_uuid,
+                                             commit=True,
                                              boot_option="netboot",
                                              boot_mode="bios")
         mock_unlink.assert_called_once_with('fake-path')
@@ -196,6 +203,7 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
         self.swap_mb = 512
         self.ephemeral_mb = 0
         self.configdrive_mb = 0
+        self.node_uuid = "12345678-1234-1234-1234-1234567890abcxyz"
 
     def _get_parted_cmd(self, dev):
         return ['parted', '-a', 'optimal', '-s', dev,
@@ -209,7 +217,7 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
         mock_exc.return_value = (None, None)
         disk_utils.make_partitions(self.dev, self.root_mb, self.swap_mb,
                                    self.ephemeral_mb, self.configdrive_mb,
-                                   boot_option=boot_option)
+                                   self.node_uuid, boot_option=boot_option)
 
         expected_mkpart = ['mkpart', 'primary', 'linux-swap', '1', '513',
                            'mkpart', 'primary', '', '513', '1537']
@@ -239,7 +247,8 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
         cmd = self._get_parted_cmd(self.dev) + expected_mkpart
         mock_exc.return_value = (None, None)
         disk_utils.make_partitions(self.dev, self.root_mb, self.swap_mb,
-                                   self.ephemeral_mb, self.configdrive_mb)
+                                   self.ephemeral_mb, self.configdrive_mb,
+                                   self.node_uuid)
 
         parted_call = mock.call(*cmd, run_as_root=True, check_exit_code=[0])
         mock_exc.assert_has_calls([parted_call])
@@ -250,55 +259,14 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
                            'mkpart', 'primary', 'linux-swap', '2049', '2561',
                            'mkpart', 'primary', '', '2561', '3585']
         self.dev = 'fake-dev'
-        expected_result = {'ephemeral': 'fake-dev1',
-                           'swap': 'fake-dev2',
-                           'root': 'fake-dev3'}
+        expected_result = {'ephemeral': 'fake-dev-part1',
+                           'swap': 'fake-dev-part2',
+                           'root': 'fake-dev-part3'}
         cmd = self._get_parted_cmd(self.dev) + expected_mkpart
         mock_exc.return_value = (None, None)
         result = disk_utils.make_partitions(
             self.dev, self.root_mb, self.swap_mb, self.ephemeral_mb,
-            self.configdrive_mb)
-
-        parted_call = mock.call(*cmd, run_as_root=True, check_exit_code=[0])
-        mock_exc.assert_has_calls([parted_call])
-        self.assertEqual(expected_result, result)
-
-    def test_make_partitions_with_iscsi_device(self, mock_exc):
-        self.ephemeral_mb = 2048
-        expected_mkpart = ['mkpart', 'primary', '', '1', '2049',
-                           'mkpart', 'primary', 'linux-swap', '2049', '2561',
-                           'mkpart', 'primary', '', '2561', '3585']
-        self.dev = 'ip-10.10.1.10:abc-iscsi-xyz-lun-123'
-        expected_result = {'ephemeral': self.dev + '-part1',
-                           'swap': self.dev + '-part2',
-                           'root': self.dev + '-part3'}
-        cmd = self._get_parted_cmd(self.dev) + expected_mkpart
-        mock_exc.return_value = (None, None)
-        result = disk_utils.make_partitions(
-            self.dev, self.root_mb, self.swap_mb, self.ephemeral_mb,
-            self.configdrive_mb)
-
-        parted_call = mock.call(*cmd, run_as_root=True, check_exit_code=[0])
-        mock_exc.assert_has_calls([parted_call])
-        self.assertEqual(expected_result, result)
-
-    def test_make_partitions_with_iscsi_device_uefi_local(self, mock_exc):
-        self.ephemeral_mb = 2048
-        expected_mkpart = ['mkpart', 'primary', 'fat32', '1', '201',
-                           'set', '1', 'boot', 'on',
-                           'mkpart', 'primary', '', '201', '2249',
-                           'mkpart', 'primary', 'linux-swap', '2249', '2761',
-                           'mkpart', 'primary', '', '2761', '3785']
-        self.dev = 'ip-10.10.1.10:abc-iscsi-xyz-lun-123'
-        expected_result = {'efi system partition': self.dev + '-part1',
-                           'ephemeral': self.dev + '-part2',
-                           'swap': self.dev + '-part3',
-                           'root': self.dev + '-part4'}
-        cmd = self._get_parted_cmd_uefi(self.dev) + expected_mkpart
-        mock_exc.return_value = (None, None)
-        result = disk_utils.make_partitions(
-            self.dev, self.root_mb, self.swap_mb, self.ephemeral_mb,
-            self.configdrive_mb, boot_option='local', boot_mode='uefi')
+            self.configdrive_mb, self.node_uuid)
 
         parted_call = mock.call(*cmd, run_as_root=True, check_exit_code=[0])
         mock_exc.assert_has_calls([parted_call])
@@ -571,11 +539,3 @@ class OtherFunctionTestCase(test_base.BaseTestCase):
             return_value=mb + 1)
         self.assertEqual(2, disk_utils.get_image_mb('x', False))
         self.assertEqual(2, disk_utils.get_image_mb('x', True))
-
-    def test_is_iscsi_device_True(self):
-        device = '/dev/disk/by-path/ip-1.2.3.4:5678-iscsi-iqn.fake-lun-9'
-        self.assertTrue(disk_utils.is_iscsi_device(device))
-
-    def test_is_iscsi_device_False(self):
-        device = '/dev/disk/by-path/fake-dev'
-        self.assertFalse(disk_utils.is_iscsi_device(device))
